@@ -10,5 +10,6 @@ po = po4.purchaseOrder(orderDate=xs.date(1999, 10, 20))
 po.shipTo = address.USAddress('Alice Smith', '123 Maple Street', 'Anytown', 'AK', 12341)
 po.billTo = address.USAddress('Robert Smith', '8 Oak Avenue', 'Anytown', 'AK', 12341)
 
+# Disable validation since content is incomplete.
 pyxb.RequireValidWhenGenerating(False)
-print(po.toxml("utf-8"))
+print(po.toxml("utf-8").decode('utf-8'))
