@@ -10,4 +10,4 @@ po.billTo = address.USAddress('Robert Smith', '8 Oak Avenue', 'Anytown', 'AK', 1
 po.items = pyxb.BIND(pyxb.BIND('Lapis necklace', 1, 99.95, partNum='833-AA'),
                      pyxb.BIND('Plastic necklace', 4, 3.95, partNum='833-AB'))
 
-print(po.toxml("utf-8"))
+print(po.toxml("utf-8").decode('utf-8'))
