@@ -1,9 +1,7 @@
 #!/bin/sh
 
-fail () {
-  echo 1>&2 "${test_name} FAILED: ${@}"
-  exit 1
-}
+: ${PYXB_TEST_ROOT:=${PYXB_ROOT}/tests}
+. ${PYXB_TEST_ROOT}/support.sh
 
 # Because this is an OpenGIS application, the OpenGIS bundle must be
 # made available during binding generation.  OpenGIS also depends
@@ -11,7 +9,7 @@ fail () {
 export PYXB_ARCHIVE_PATH='&pyxb/bundles/opengis//:&pyxb/bundles/common//:+'
 
 # Attempt to get romkan.py if not already available
-[ -f romkan.py ] || wget http://mhagiwara.googlecode.com/svn/trunk/nltk/jpbook/romkan.py
+[ -f romkan.py ] || wget https://raw.githubusercontent.com/mhagiwara/nltk/master/jpbook/romkan.py
 
 python -c 'import drv_libxml2' || fail python-libxml2 not installed
 
@@ -27,14 +25,12 @@ opengis bundle directory.
 EOText
 fi
 
-# This allows this script to run under the autotest environment, where
-# output is sent to a file.
-export PYTHONIOENCODING='utf-8'
-
-rm fgd_gml.*
+rm -f fgd_gml.*
 # A customized pyxbgen is required to do the translation
 ./pyxbgen_jp \
-   --schema-location=data/shift_jis/FGD_GMLSchema.xsd --module=fgd_gml
+    --schema-location=data/shift_jis/FGD_GMLSchema.xsd --module=fgd_gml \
+    || fail generating bindings
 
 # Make sure it worked
-python check.py
+python check.py || fail check
+passed
