@@ -1,5 +1,4 @@
-PYXB_ROOT=${PYXB_ROOT:-/opt/pyxb}
+PYXB_ROOT=${PYXB_ROOT:-/mnt/devel/pyxb}
 PYTHONPATH=${PYXB_ROOT}:${PYTHONPATH:+:${PYTHONPATH}}
 PATH="${PYXB_ROOT}/scripts:${PYXB_ROOT}/bin:${PATH}"
 export PYXB_ROOT PYTHONPATH PATH
-
