@@ -1,7 +1,7 @@
 # ./pyxb/bundles/dc/raw/dc.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:fde543a00b9681daae05bbc5a17f3dce9cfacb0c
-# Generated 2016-09-18 17:34:12.275854 by PyXB version 1.2.5 using Python 2.7.12.final.0
+# Generated 2017-09-03 06:16:52.065723 by PyXB version 1.2.6 using Python 2.7.12.final.0
 # Namespace http://purl.org/dc/elements/1.1/ [xmlns:dc]
 
 from __future__ import unicode_literals
@@ -14,10 +14,10 @@ import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:05ad5056-7df0-11e6-9fa4-3497f68b2e96')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:62cca554-9099-11e7-b77e-3497f68b2e96')
 
 # Version of PyXB used to generate the bindings
-_PyXBVersion = '1.2.5'
+_PyXBVersion = '1.2.6'
 # Generated bindings are not compatible across PyXB versions
 if pyxb.__version__ != _PyXBVersion:
     raise pyxb.PyXBVersionError(_PyXBVersion)
@@ -94,7 +94,7 @@ class SimpleLiteral (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_MIXED
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'SimpleLiteral')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 45, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 45, 2)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
@@ -102,11 +102,10 @@ class SimpleLiteral (pyxb.binding.basis.complexTypeDefinition):
     # Attribute {http://www.w3.org/XML/1998/namespace}lang uses Python identifier lang
     __lang = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.XML, 'lang'), 'lang', '__httppurl_orgdcelements1_1_SimpleLiteral_httpwww_w3_orgXML1998namespacelang', pyxb.binding.xml_.STD_ANON_lang)
     __lang._DeclarationLocation = None
-    __lang._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 65, 5)
+    __lang._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 65, 5)
     
     lang = property(__lang.value, __lang.set, None, None)
 
-    _HasWildcardElement = True
     _ElementMap.update({
         
     })
@@ -127,13 +126,13 @@ class elementContainer (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'elementContainer')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 104, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 104, 2)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
     # Element {http://purl.org/dc/elements/1.1/}any uses Python identifier any
-    __any = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'any'), 'any', '__httppurl_orgdcelements1_1_elementContainer_httppurl_orgdcelements1_1any', True, pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 70, 2), )
+    __any = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'any'), 'any', '__httppurl_orgdcelements1_1_elementContainer_httppurl_orgdcelements1_1any', True, pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 70, 2), )
 
     
     any = property(__any.value, __any.set, None, None)
@@ -148,52 +147,52 @@ _module_typeBindings.elementContainer = elementContainer
 Namespace.addCategoryObject('typeBinding', 'elementContainer', elementContainer)
 
 
-title = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'title'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 72, 2))
+title = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'title'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 72, 2))
 Namespace.addCategoryObject('elementBinding', title.name().localName(), title)
 
-creator = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'creator'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 73, 2))
+creator = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'creator'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 73, 2))
 Namespace.addCategoryObject('elementBinding', creator.name().localName(), creator)
 
-subject = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subject'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 74, 2))
+subject = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subject'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 74, 2))
 Namespace.addCategoryObject('elementBinding', subject.name().localName(), subject)
 
-description = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'description'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 75, 2))
+description = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'description'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 75, 2))
 Namespace.addCategoryObject('elementBinding', description.name().localName(), description)
 
-publisher = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'publisher'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 76, 2))
+publisher = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'publisher'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 76, 2))
 Namespace.addCategoryObject('elementBinding', publisher.name().localName(), publisher)
 
-contributor = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'contributor'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 77, 2))
+contributor = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'contributor'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 77, 2))
 Namespace.addCategoryObject('elementBinding', contributor.name().localName(), contributor)
 
-date = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'date'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 78, 2))
+date = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'date'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 78, 2))
 Namespace.addCategoryObject('elementBinding', date.name().localName(), date)
 
-type = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'type'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 79, 2))
+type = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'type'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 79, 2))
 Namespace.addCategoryObject('elementBinding', type.name().localName(), type)
 
-format = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'format'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 80, 2))
+format = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'format'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 80, 2))
 Namespace.addCategoryObject('elementBinding', format.name().localName(), format)
 
-identifier = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'identifier'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 81, 2))
+identifier = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'identifier'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 81, 2))
 Namespace.addCategoryObject('elementBinding', identifier.name().localName(), identifier)
 
-source = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'source'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 82, 2))
+source = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'source'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 82, 2))
 Namespace.addCategoryObject('elementBinding', source.name().localName(), source)
 
-language = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'language'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 83, 2))
+language = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'language'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 83, 2))
 Namespace.addCategoryObject('elementBinding', language.name().localName(), language)
 
-relation = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'relation'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 84, 2))
+relation = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'relation'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 84, 2))
 Namespace.addCategoryObject('elementBinding', relation.name().localName(), relation)
 
-coverage = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'coverage'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 85, 2))
+coverage = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'coverage'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 85, 2))
 Namespace.addCategoryObject('elementBinding', coverage.name().localName(), coverage)
 
-rights = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'rights'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 86, 2))
+rights = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'rights'), pyxb.binding.datatypes.anyType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 86, 2))
 Namespace.addCategoryObject('elementBinding', rights.name().localName(), rights)
 
-any = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'any'), SimpleLiteral, abstract=pyxb.binding.datatypes.boolean(1), location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 70, 2))
+any = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'any'), SimpleLiteral, abstract=pyxb.binding.datatypes.boolean(1), location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 70, 2))
 Namespace.addCategoryObject('elementBinding', any.name().localName(), any)
 
 
@@ -205,25 +204,14 @@ def _BuildAutomaton ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0, max=0, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 63, 6))
-    counters.add(cc_0)
     states = []
-    final_update = set()
-    final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 63, 6))
-    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
-    states.append(st_0)
-    transitions = []
-    transitions.append(fac.Transition(st_0, [
-        fac.UpdateInstruction(cc_0, True) ]))
-    st_0._set_transitionSet(transitions)
     return fac.Automaton(states, counters, True, containing_state=None)
 SimpleLiteral._Automaton = _BuildAutomaton()
 
 
 
 
-elementContainer._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'any'), SimpleLiteral, abstract=pyxb.binding.datatypes.boolean(1), scope=elementContainer, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 70, 2)))
+elementContainer._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'any'), SimpleLiteral, abstract=pyxb.binding.datatypes.boolean(1), scope=elementContainer, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 70, 2)))
 
 def _BuildAutomaton_ ():
     # Remove this helper function from the namespace after it is invoked
@@ -232,12 +220,12 @@ def _BuildAutomaton_ ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 98, 4))
+    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 98, 4))
     counters.add(cc_0)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(elementContainer._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'any')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dc.xsd', 99, 6))
+    symbol = pyxb.binding.content.ElementUse(elementContainer._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'any')), pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dc.xsd', 99, 6))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     transitions = []
