@@ -1,7 +1,7 @@
 # ./pyxb/bundles/dc/raw/dcmitype.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:049d2b1ce34c6b814456fe5b9055f12be5a680b0
-# Generated 2016-09-18 17:34:12.276080 by PyXB version 1.2.5 using Python 2.7.12.final.0
+# Generated 2017-09-03 06:16:52.065960 by PyXB version 1.2.6 using Python 2.7.12.final.0
 # Namespace http://purl.org/dc/dcmitype/ [xmlns:dcmitype]
 
 from __future__ import unicode_literals
@@ -14,10 +14,10 @@ import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:05ad5056-7df0-11e6-9fa4-3497f68b2e96')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:62cca554-9099-11e7-b77e-3497f68b2e96')
 
 # Version of PyXB used to generate the bindings
-_PyXBVersion = '1.2.5'
+_PyXBVersion = '1.2.6'
 # Generated bindings are not compatible across PyXB versions
 if pyxb.__version__ != _PyXBVersion:
     raise pyxb.PyXBVersionError(_PyXBVersion)
@@ -82,7 +82,7 @@ class STD_ANON (pyxb.binding.datatypes.Name, pyxb.binding.basis.enumeration_mixi
     """An atomic simple type."""
 
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dcmitype.xsd', 33, 8)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dcmitype.xsd', 33, 8)
     _Documentation = None
 STD_ANON._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON, enum_prefix=None)
 STD_ANON.Collection = STD_ANON._CF_enumeration.addEnumeration(unicode_value='Collection', tag='Collection')
@@ -107,7 +107,7 @@ class DCMIType (pyxb.binding.basis.STD_union):
     """Simple type that is a union of STD_ANON."""
 
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'DCMIType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/dc/schemas/dcmitype.xsd', 31, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/dc/schemas/dcmitype.xsd', 31, 2)
     _Documentation = None
 
     _MemberTypes = ( STD_ANON, )
