@@ -1,7 +1,7 @@
 # ./pyxb/bundles/saml20/raw/dce.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:f6fa0461f265c04a0bd0017089ca6057a2aade76
-# Generated 2016-09-18 17:34:11.535599 by PyXB version 1.2.5 using Python 2.7.12.final.0
+# Generated 2017-09-03 06:16:51.128431 by PyXB version 1.2.6 using Python 2.7.12.final.0
 # Namespace urn:oasis:names:tc:SAML:2.0:profiles:attribute:DCE
 
 from __future__ import unicode_literals
@@ -14,10 +14,10 @@ import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:0541def2-7df0-11e6-9fa4-3497f68b2e96')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:6244a514-9099-11e7-b77e-3497f68b2e96')
 
 # Version of PyXB used to generate the bindings
-_PyXBVersion = '1.2.5'
+_PyXBVersion = '1.2.6'
 # Generated bindings are not compatible across PyXB versions
 if pyxb.__version__ != _PyXBVersion:
     raise pyxb.PyXBVersionError(_PyXBVersion)
@@ -83,23 +83,23 @@ class DCEValueType (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'DCEValueType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/dce.xsd', 18, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/saml20/schemas/dce.xsd', 18, 4)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyURI
     
     # Attribute {urn:oasis:names:tc:SAML:2.0:profiles:attribute:DCE}Realm uses Python identifier Realm
     __Realm = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(Namespace, 'Realm'), 'Realm', '__urnoasisnamestcSAML2_0profilesattributeDCE_DCEValueType_urnoasisnamestcSAML2_0profilesattributeDCERealm', pyxb.binding.datatypes.anyURI)
-    __Realm._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/dce.xsd', 26, 4)
-    __Realm._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/dce.xsd', 21, 16)
+    __Realm._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/saml20/schemas/dce.xsd', 26, 4)
+    __Realm._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/saml20/schemas/dce.xsd', 21, 16)
     
     Realm = property(__Realm.value, __Realm.set, None, None)
 
     
     # Attribute {urn:oasis:names:tc:SAML:2.0:profiles:attribute:DCE}FriendlyName uses Python identifier FriendlyName
     __FriendlyName = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(Namespace, 'FriendlyName'), 'FriendlyName', '__urnoasisnamestcSAML2_0profilesattributeDCE_DCEValueType_urnoasisnamestcSAML2_0profilesattributeDCEFriendlyName', pyxb.binding.datatypes.string)
-    __FriendlyName._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/dce.xsd', 27, 4)
-    __FriendlyName._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/dce.xsd', 22, 16)
+    __FriendlyName._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/saml20/schemas/dce.xsd', 27, 4)
+    __FriendlyName._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/saml20/schemas/dce.xsd', 22, 16)
     
     FriendlyName = property(__FriendlyName.value, __FriendlyName.set, None, None)
 
