@@ -1,7 +1,7 @@
 # ./pyxb/bundles/saml20/raw/x500.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:98344aaf7fd05f232dfec562262a7a9f0df31d06
-# Generated 2016-09-18 17:34:11.839580 by PyXB version 1.2.5 using Python 2.7.12.final.0
+# Generated 2017-09-03 06:16:51.531313 by PyXB version 1.2.6 using Python 2.7.12.final.0
 # Namespace urn:oasis:names:tc:SAML:2.0:profiles:attribute:X500
 
 from __future__ import unicode_literals
@@ -14,10 +14,10 @@ import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:0570eb34-7df0-11e6-9fa4-3497f68b2e96')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:62826a34-9099-11e7-b77e-3497f68b2e96')
 
 # Version of PyXB used to generate the bindings
-_PyXBVersion = '1.2.5'
+_PyXBVersion = '1.2.6'
 # Generated bindings are not compatible across PyXB versions
 if pyxb.__version__ != _PyXBVersion:
     raise pyxb.PyXBVersionError(_PyXBVersion)
