@@ -1,7 +1,7 @@
 # ./pyxb/bundles/saml20/raw/xacml.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:133882c271c9c058c288b5e7f4206ed0d3448e5d
-# Generated 2016-09-18 17:34:12.003278 by PyXB version 1.2.5 using Python 2.7.12.final.0
+# Generated 2017-09-03 06:16:51.691398 by PyXB version 1.2.6 using Python 2.7.12.final.0
 # Namespace urn:oasis:names:tc:SAML:2.0:profiles:attribute:XACML
 
 from __future__ import unicode_literals
@@ -14,10 +14,10 @@ import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:05898e5a-7df0-11e6-9fa4-3497f68b2e96')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:629a694a-9099-11e7-b77e-3497f68b2e96')
 
 # Version of PyXB used to generate the bindings
-_PyXBVersion = '1.2.5'
+_PyXBVersion = '1.2.6'
 # Generated bindings are not compatible across PyXB versions
 if pyxb.__version__ != _PyXBVersion:
     raise pyxb.PyXBVersionError(_PyXBVersion)
