@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/httpbind.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:700d4ca8e0588f8b897f9c60d123e08fa4d56b36
-# Generated 2016-09-18 17:34:05.378097 by PyXB version 1.2.5 using Python 2.7.12.final.0
+# Generated 2017-09-03 06:16:44.974001 by PyXB version 1.2.6 using Python 2.7.12.final.0
 # Namespace http://schemas.xmlsoap.org/wsdl/http/
 
 from __future__ import unicode_literals
@@ -14,10 +14,10 @@ import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:019379e6-7df0-11e6-9fa4-3497f68b2e96')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:5e96d752-9099-11e7-b77e-3497f68b2e96')
 
 # Version of PyXB used to generate the bindings
-_PyXBVersion = '1.2.5'
+_PyXBVersion = '1.2.6'
 # Generated bindings are not compatible across PyXB versions
 if pyxb.__version__ != _PyXBVersion:
     raise pyxb.PyXBVersionError(_PyXBVersion)
@@ -84,7 +84,7 @@ class addressType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'addressType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 42, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 42, 4)
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
     _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
     # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
@@ -93,8 +93,8 @@ class addressType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     
     # Attribute location uses Python identifier location
     __location = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'location'), 'location', '__httpschemas_xmlsoap_orgwsdlhttp_addressType_location', pyxb.binding.datatypes.anyURI, required=True)
-    __location._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 46, 6)
-    __location._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 46, 6)
+    __location._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 46, 6)
+    __location._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 46, 6)
     
     location = property(__location.value, __location.set, None, None)
 
@@ -115,7 +115,7 @@ class bindingType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'bindingType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 52, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 52, 4)
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
     _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
     # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
@@ -124,8 +124,8 @@ class bindingType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     
     # Attribute verb uses Python identifier verb
     __verb = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'verb'), 'verb', '__httpschemas_xmlsoap_orgwsdlhttp_bindingType_verb', pyxb.binding.datatypes.NMTOKEN, required=True)
-    __verb._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 56, 9)
-    __verb._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 56, 9)
+    __verb._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 56, 9)
+    __verb._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 56, 9)
     
     verb = property(__verb.value, __verb.set, None, None)
 
@@ -146,7 +146,7 @@ class operationType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'operationType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 62, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 62, 4)
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
     _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
     # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
@@ -155,8 +155,8 @@ class operationType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     
     # Attribute location uses Python identifier location
     __location = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'location'), 'location', '__httpschemas_xmlsoap_orgwsdlhttp_operationType_location', pyxb.binding.datatypes.anyURI, required=True)
-    __location._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 66, 9)
-    __location._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 66, 9)
+    __location._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 66, 9)
+    __location._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 66, 9)
     
     location = property(__location.value, __location.set, None, None)
 
@@ -177,7 +177,7 @@ class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 72, 8)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 72, 8)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
@@ -197,7 +197,7 @@ class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 75, 8)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 75, 8)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
@@ -210,17 +210,17 @@ class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
 _module_typeBindings.CTD_ANON_ = CTD_ANON_
 
 
-address = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'address'), addressType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 40, 4))
+address = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'address'), addressType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 40, 4))
 Namespace.addCategoryObject('elementBinding', address.name().localName(), address)
 
-binding = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'binding'), bindingType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 51, 4))
+binding = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'binding'), bindingType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 51, 4))
 Namespace.addCategoryObject('elementBinding', binding.name().localName(), binding)
 
-operation = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'operation'), operationType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 61, 4))
+operation = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'operation'), operationType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 61, 4))
 Namespace.addCategoryObject('elementBinding', operation.name().localName(), operation)
 
-urlEncoded = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'urlEncoded'), CTD_ANON, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 71, 4))
+urlEncoded = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'urlEncoded'), CTD_ANON, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 71, 4))
 Namespace.addCategoryObject('elementBinding', urlEncoded.name().localName(), urlEncoded)
 
-urlReplacement = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'urlReplacement'), CTD_ANON_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 74, 4))
+urlReplacement = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'urlReplacement'), CTD_ANON_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/httpbind.xsd', 74, 4))
 Namespace.addCategoryObject('elementBinding', urlReplacement.name().localName(), urlReplacement)
