@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/mimebind.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:5404248094c8a480a41150c00669c3a55d100562
-# Generated 2016-09-18 17:34:05.519523 by PyXB version 1.2.5 using Python 2.7.12.final.0
+# Generated 2017-09-03 06:16:45.108000 by PyXB version 1.2.6 using Python 2.7.12.final.0
 # Namespace http://schemas.xmlsoap.org/wsdl/mime/
 
 from __future__ import unicode_literals
@@ -14,10 +14,10 @@ import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:01aa0cf6-7df0-11e6-9fa4-3497f68b2e96')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:5eabc0b8-9099-11e7-b77e-3497f68b2e96')
 
 # Version of PyXB used to generate the bindings
-_PyXBVersion = '1.2.5'
+_PyXBVersion = '1.2.6'
 # Generated bindings are not compatible across PyXB versions
 if pyxb.__version__ != _PyXBVersion:
     raise pyxb.PyXBVersionError(_PyXBVersion)
@@ -84,7 +84,7 @@ class contentType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'contentType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 39, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 39, 4)
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
     _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
     # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
@@ -93,16 +93,16 @@ class contentType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     
     # Attribute type uses Python identifier type
     __type = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'type'), 'type', '__httpschemas_xmlsoap_orgwsdlmime_contentType_type', pyxb.binding.datatypes.string)
-    __type._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 43, 9)
-    __type._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 43, 9)
+    __type._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 43, 9)
+    __type._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 43, 9)
     
     type = property(__type.value, __type.set, None, None)
 
     
     # Attribute part uses Python identifier part
     __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'part'), 'part', '__httpschemas_xmlsoap_orgwsdlmime_contentType_part', pyxb.binding.datatypes.NMTOKEN)
-    __part._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 44, 9)
-    __part._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 44, 9)
+    __part._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 44, 9)
+    __part._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 44, 9)
     
     part = property(__part.value, __part.set, None, None)
 
@@ -124,13 +124,13 @@ class multipartRelatedType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'multipartRelatedType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 49, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 49, 4)
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
     _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
     # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
     
     # Element part uses Python identifier part
-    __part = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(None, 'part'), 'part', '__httpschemas_xmlsoap_orgwsdlmime_multipartRelatedType_part', True, pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 53, 10), )
+    __part = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(None, 'part'), 'part', '__httpschemas_xmlsoap_orgwsdlmime_multipartRelatedType_part', True, pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 53, 10), )
 
     
     part = property(__part.value, __part.set, None, None)
@@ -154,15 +154,15 @@ class tPart (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'tPart')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 58, 7)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 58, 7)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
     # Attribute name uses Python identifier name
     __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'name'), 'name', '__httpschemas_xmlsoap_orgwsdlmime_tPart_name', pyxb.binding.datatypes.NMTOKEN, required=True)
-    __name._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 62, 9)
-    __name._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 62, 9)
+    __name._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 62, 9)
+    __name._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 62, 9)
     
     name = property(__name.value, __name.set, None, None)
 
@@ -184,7 +184,7 @@ class tMimeXml (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'tMimeXml')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 65, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 65, 4)
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
     _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
     # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
@@ -193,8 +193,8 @@ class tMimeXml (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     
     # Attribute part uses Python identifier part
     __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'part'), 'part', '__httpschemas_xmlsoap_orgwsdlmime_tMimeXml_part', pyxb.binding.datatypes.NMTOKEN)
-    __part._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 69, 3)
-    __part._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 69, 3)
+    __part._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 69, 3)
+    __part._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 69, 3)
     
     part = property(__part.value, __part.set, None, None)
 
@@ -208,18 +208,18 @@ _module_typeBindings.tMimeXml = tMimeXml
 Namespace.addCategoryObject('typeBinding', 'tMimeXml', tMimeXml)
 
 
-content = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'content'), contentType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 38, 4))
+content = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'content'), contentType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 38, 4))
 Namespace.addCategoryObject('elementBinding', content.name().localName(), content)
 
-multipartRelated = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'multipartRelated'), multipartRelatedType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 48, 4))
+multipartRelated = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'multipartRelated'), multipartRelatedType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 48, 4))
 Namespace.addCategoryObject('elementBinding', multipartRelated.name().localName(), multipartRelated)
 
-mimeXml = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'mimeXml'), tMimeXml, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 64, 4))
+mimeXml = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'mimeXml'), tMimeXml, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 64, 4))
 Namespace.addCategoryObject('elementBinding', mimeXml.name().localName(), mimeXml)
 
 
 
-multipartRelatedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, 'part'), tPart, scope=multipartRelatedType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 53, 10)))
+multipartRelatedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, 'part'), tPart, scope=multipartRelatedType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 53, 10)))
 
 def _BuildAutomaton ():
     # Remove this helper function from the namespace after it is invoked
@@ -228,12 +228,12 @@ def _BuildAutomaton ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 53, 10))
+    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 53, 10))
     counters.add(cc_0)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(multipartRelatedType._UseForTag(pyxb.namespace.ExpandedName(None, 'part')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 53, 10))
+    symbol = pyxb.binding.content.ElementUse(multipartRelatedType._UseForTag(pyxb.namespace.ExpandedName(None, 'part')), pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 53, 10))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     transitions = []
@@ -253,12 +253,12 @@ def _BuildAutomaton_ ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 60, 9))
+    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 60, 9))
     counters.add(cc_0)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_strict, namespace_constraint=set(['http://schemas.xmlsoap.org/wsdl/mime/'])), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 60, 9))
+    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_strict, namespace_constraint=set(['http://schemas.xmlsoap.org/wsdl/mime/'])), pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/mimebind.xsd', 60, 9))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     transitions = []
