@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/sawsdl.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:070b3b59f767ac4d0f19e851fc2c1f39e654364d
-# Generated 2016-09-18 17:34:10.215324 by PyXB version 1.2.5 using Python 2.7.12.final.0
+# Generated 2017-09-03 06:16:49.734741 by PyXB version 1.2.6 using Python 2.7.12.final.0
 # Namespace http://www.w3.org/ns/sawsdl
 
 from __future__ import unicode_literals
@@ -14,10 +14,10 @@ import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:04787b0c-7df0-11e6-9fa4-3497f68b2e96')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:616f95f4-9099-11e7-b77e-3497f68b2e96')
 
 # Version of PyXB used to generate the bindings
-_PyXBVersion = '1.2.5'
+_PyXBVersion = '1.2.6'
 # Generated bindings are not compatible across PyXB versions
 if pyxb.__version__ != _PyXBVersion:
     raise pyxb.PyXBVersionError(_PyXBVersion)
@@ -83,7 +83,7 @@ class listOfAnyURI (pyxb.binding.basis.STD_list):
     """Simple type that is a list of pyxb.binding.datatypes.anyURI."""
 
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'listOfAnyURI')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/sawsdl.xsd', 8, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/sawsdl.xsd', 8, 2)
     _Documentation = None
 
     _ItemType = pyxb.binding.datatypes.anyURI
@@ -99,7 +99,7 @@ class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/sawsdl.xsd', 17, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/sawsdl.xsd', 17, 4)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
@@ -113,5 +113,5 @@ class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
 _module_typeBindings.CTD_ANON = CTD_ANON
 
 
-attrExtensions = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'attrExtensions'), CTD_ANON, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/sawsdl.xsd', 16, 2))
+attrExtensions = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'attrExtensions'), CTD_ANON, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/sawsdl.xsd', 16, 2))
 Namespace.addCategoryObject('elementBinding', attrExtensions.name().localName(), attrExtensions)
