@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/whttp.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:b6d8cfb74f55bcb68c30cab97a9555b1fa1c0cfa
-# Generated 2016-09-18 17:34:06.633362 by PyXB version 1.2.5 using Python 2.7.12.final.0
+# Generated 2017-09-03 06:16:46.356143 by PyXB version 1.2.6 using Python 2.7.12.final.0
 # Namespace http://www.w3.org/ns/wsdl/http
 
 from __future__ import unicode_literals
@@ -14,10 +14,10 @@ import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:0253219c-7df0-11e6-9fa4-3497f68b2e96')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:5f673cbc-9099-11e7-b77e-3497f68b2e96')
 
 # Version of PyXB used to generate the bindings
-_PyXBVersion = '1.2.5'
+_PyXBVersion = '1.2.6'
 # Generated bindings are not compatible across PyXB versions
 if pyxb.__version__ != _PyXBVersion:
     raise pyxb.PyXBVersionError(_PyXBVersion)
@@ -85,7 +85,7 @@ class STD_ANON (pyxb.binding.datatypes.token, pyxb.binding.basis.enumeration_mix
     """An atomic simple type."""
 
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/whttp.xsd', 34, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/whttp.xsd', 34, 1)
     _Documentation = None
 STD_ANON._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON, enum_prefix=None)
 STD_ANON.any = STD_ANON._CF_enumeration.addEnumeration(unicode_value='#any', tag='any')
@@ -98,13 +98,13 @@ class queryParameterType (pyxb.binding.datatypes.string):
     """An atomic simple type."""
 
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'queryParameterType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/whttp.xsd', 49, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/whttp.xsd', 49, 2)
     _Documentation = None
+queryParameterType._CF_length = pyxb.binding.facets.CF_length(value=pyxb.binding.datatypes.nonNegativeInteger(1))
 queryParameterType._CF_pattern = pyxb.binding.facets.CF_pattern()
 queryParameterType._CF_pattern.addPattern(pattern="[&;a-zA-Z0-9\\-\\._~!$'\\(\\):@/\\?\\*\\+,]{1,1}")
-queryParameterType._CF_length = pyxb.binding.facets.CF_length(value=pyxb.binding.datatypes.nonNegativeInteger(1))
-queryParameterType._InitializeFacetMap(queryParameterType._CF_pattern,
-   queryParameterType._CF_length)
+queryParameterType._InitializeFacetMap(queryParameterType._CF_length,
+   queryParameterType._CF_pattern)
 Namespace.addCategoryObject('typeBinding', 'queryParameterType', queryParameterType)
 _module_typeBindings.queryParameterType = queryParameterType
 
@@ -114,7 +114,7 @@ class STD_ANON_ (pyxb.binding.datatypes.token, pyxb.binding.basis.enumeration_mi
     """An atomic simple type."""
 
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/whttp.xsd', 65, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/whttp.xsd', 65, 4)
     _Documentation = None
 STD_ANON_._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON_, enum_prefix=None)
 STD_ANON_.basic = STD_ANON_._CF_enumeration.addEnumeration(unicode_value='basic', tag='basic')
@@ -128,7 +128,7 @@ class versionType (pyxb.binding.datatypes.string):
     """An atomic simple type."""
 
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'versionType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/whttp.xsd', 74, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/whttp.xsd', 74, 2)
     _Documentation = None
 versionType._CF_pattern = pyxb.binding.facets.CF_pattern()
 versionType._CF_pattern.addPattern(pattern='[0-9]+\\.[0-9]+')
@@ -142,7 +142,7 @@ class httpTokenType (pyxb.binding.datatypes.string):
     """An atomic simple type."""
 
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'httpTokenType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/whttp.xsd', 80, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/whttp.xsd', 80, 2)
     _Documentation = None
 httpTokenType._CF_pattern = pyxb.binding.facets.CF_pattern()
 httpTokenType._CF_pattern.addPattern(pattern="[!#-'*+\\-.0-9A-Z^-z|~]+")
@@ -157,15 +157,15 @@ class STD_ANON_2 (pyxb.binding.basis.STD_union):
     """Simple type that is a union of pyxb.binding.datatypes.int, STD_ANON."""
 
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/whttp.xsd', 32, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/whttp.xsd', 32, 4)
     _Documentation = None
 
     _MemberTypes = ( pyxb.binding.datatypes.int, STD_ANON, )
-STD_ANON_2._CF_pattern = pyxb.binding.facets.CF_pattern()
 STD_ANON_2._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON_2)
+STD_ANON_2._CF_pattern = pyxb.binding.facets.CF_pattern()
 STD_ANON_2.any = '#any'                           # originally STD_ANON.any
-STD_ANON_2._InitializeFacetMap(STD_ANON_2._CF_pattern,
-   STD_ANON_2._CF_enumeration)
+STD_ANON_2._InitializeFacetMap(STD_ANON_2._CF_enumeration,
+   STD_ANON_2._CF_pattern)
 _module_typeBindings.STD_ANON_2 = STD_ANON_2
 
 # Complex type [anonymous] with content type ELEMENT_ONLY
@@ -175,7 +175,7 @@ class CTD_ANON (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/whttp.xsd', 87, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/whttp.xsd', 87, 4)
     _ElementMap = pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType._ElementMap.copy()
     _AttributeMap = pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType._AttributeMap.copy()
     # Base type is pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType
@@ -184,24 +184,24 @@ class CTD_ANON (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     
     # Attribute name uses Python identifier name
     __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'name'), 'name', '__httpwww_w3_orgnswsdlhttp_CTD_ANON_name', _module_typeBindings.httpTokenType, required=True)
-    __name._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/whttp.xsd', 90, 3)
-    __name._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/whttp.xsd', 90, 3)
+    __name._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/whttp.xsd', 90, 3)
+    __name._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/whttp.xsd', 90, 3)
     
     name = property(__name.value, __name.set, None, None)
 
     
     # Attribute type uses Python identifier type
     __type = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'type'), 'type', '__httpwww_w3_orgnswsdlhttp_CTD_ANON_type', pyxb.binding.datatypes.QName, required=True)
-    __type._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/whttp.xsd', 91, 3)
-    __type._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/whttp.xsd', 91, 3)
+    __type._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/whttp.xsd', 91, 3)
+    __type._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/whttp.xsd', 91, 3)
     
     type = property(__type.value, __type.set, None, None)
 
     
     # Attribute required uses Python identifier required
     __required = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'required'), 'required', '__httpwww_w3_orgnswsdlhttp_CTD_ANON_required', pyxb.binding.datatypes.boolean)
-    __required._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/whttp.xsd', 92, 3)
-    __required._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/whttp.xsd', 92, 3)
+    __required._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/whttp.xsd', 92, 3)
+    __required._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/whttp.xsd', 92, 3)
     
     required = property(__required.value, __required.set, None, None)
 
@@ -217,7 +217,7 @@ class CTD_ANON (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
 _module_typeBindings.CTD_ANON = CTD_ANON
 
 
-header = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'header'), CTD_ANON, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/whttp.xsd', 86, 2))
+header = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'header'), CTD_ANON, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/whttp.xsd', 86, 2))
 Namespace.addCategoryObject('elementBinding', header.name().localName(), header)
 
 
@@ -229,12 +229,12 @@ def _BuildAutomaton ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
+    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
     counters.add(cc_0)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(_Namespace_wsdl, 'documentation')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(_Namespace_wsdl, 'documentation')), pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     transitions = []
