@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/wsa.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:0ecbd27a42302a2dbf33a51269e14ce6419c0738
-# Generated 2016-09-18 17:34:08.032711 by PyXB version 1.2.5 using Python 2.7.12.final.0
+# Generated 2017-09-03 06:16:47.595298 by PyXB version 1.2.6 using Python 2.7.12.final.0
 # Namespace http://www.w3.org/2005/08/addressing
 
 from __future__ import unicode_literals
@@ -14,10 +14,10 @@ import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:03298d90-7df0-11e6-9fa4-3497f68b2e96')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:6027cb30-9099-11e7-b77e-3497f68b2e96')
 
 # Version of PyXB used to generate the bindings
-_PyXBVersion = '1.2.5'
+_PyXBVersion = '1.2.6'
 # Generated bindings are not compatible across PyXB versions
 if pyxb.__version__ != _PyXBVersion:
     raise pyxb.PyXBVersionError(_PyXBVersion)
@@ -82,7 +82,7 @@ class RelationshipType (pyxb.binding.datatypes.anyURI, pyxb.binding.basis.enumer
     """An atomic simple type."""
 
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'RelationshipType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 64, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 64, 1)
     _Documentation = None
 RelationshipType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=RelationshipType, enum_prefix=None)
 RelationshipType.httpwww_w3_org200508addressingreply = RelationshipType._CF_enumeration.addEnumeration(unicode_value='http://www.w3.org/2005/08/addressing/reply', tag='httpwww_w3_org200508addressingreply')
@@ -96,7 +96,7 @@ class FaultCodesType (pyxb.binding.datatypes.QName, pyxb.binding.basis.enumerati
     """An atomic simple type."""
 
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'FaultCodesType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 92, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 92, 1)
     _Documentation = None
 FaultCodesType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=FaultCodesType, enum_prefix=None)
 FaultCodesType._CF_enumeration.addEnumeration(value=pyxb.namespace.ExpandedName(Namespace, 'InvalidAddressingHeader'), tag=None)
@@ -121,15 +121,15 @@ class RelationshipTypeOpenEnum (pyxb.binding.basis.STD_union):
     """Simple type that is a union of RelationshipType, pyxb.binding.datatypes.anyURI."""
 
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'RelationshipTypeOpenEnum')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 60, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 60, 1)
     _Documentation = None
 
     _MemberTypes = ( RelationshipType, pyxb.binding.datatypes.anyURI, )
-RelationshipTypeOpenEnum._CF_pattern = pyxb.binding.facets.CF_pattern()
 RelationshipTypeOpenEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=RelationshipTypeOpenEnum)
+RelationshipTypeOpenEnum._CF_pattern = pyxb.binding.facets.CF_pattern()
 RelationshipTypeOpenEnum.httpwww_w3_org200508addressingreply = 'http://www.w3.org/2005/08/addressing/reply'# originally RelationshipType.httpwww_w3_org200508addressingreply
-RelationshipTypeOpenEnum._InitializeFacetMap(RelationshipTypeOpenEnum._CF_pattern,
-   RelationshipTypeOpenEnum._CF_enumeration)
+RelationshipTypeOpenEnum._InitializeFacetMap(RelationshipTypeOpenEnum._CF_enumeration,
+   RelationshipTypeOpenEnum._CF_pattern)
 Namespace.addCategoryObject('typeBinding', 'RelationshipTypeOpenEnum', RelationshipTypeOpenEnum)
 _module_typeBindings.RelationshipTypeOpenEnum = RelationshipTypeOpenEnum
 
@@ -140,14 +140,14 @@ class FaultCodesOpenEnumType (pyxb.binding.basis.STD_union):
     """Simple type that is a union of FaultCodesType, pyxb.binding.datatypes.QName."""
 
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'FaultCodesOpenEnumType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 88, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 88, 1)
     _Documentation = None
 
     _MemberTypes = ( FaultCodesType, pyxb.binding.datatypes.QName, )
-FaultCodesOpenEnumType._CF_pattern = pyxb.binding.facets.CF_pattern()
 FaultCodesOpenEnumType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=FaultCodesOpenEnumType)
-FaultCodesOpenEnumType._InitializeFacetMap(FaultCodesOpenEnumType._CF_pattern,
-   FaultCodesOpenEnumType._CF_enumeration)
+FaultCodesOpenEnumType._CF_pattern = pyxb.binding.facets.CF_pattern()
+FaultCodesOpenEnumType._InitializeFacetMap(FaultCodesOpenEnumType._CF_enumeration,
+   FaultCodesOpenEnumType._CF_pattern)
 Namespace.addCategoryObject('typeBinding', 'FaultCodesOpenEnumType', FaultCodesOpenEnumType)
 _module_typeBindings.FaultCodesOpenEnumType = FaultCodesOpenEnumType
 
@@ -158,27 +158,27 @@ class EndpointReferenceType (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'EndpointReferenceType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 23, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 23, 1)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
     # Element {http://www.w3.org/2005/08/addressing}Address uses Python identifier Address
-    __Address = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Address'), 'Address', '__httpwww_w3_org200508addressing_EndpointReferenceType_httpwww_w3_org200508addressingAddress', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 25, 3), )
+    __Address = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Address'), 'Address', '__httpwww_w3_org200508addressing_EndpointReferenceType_httpwww_w3_org200508addressingAddress', False, pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 25, 3), )
 
     
     Address = property(__Address.value, __Address.set, None, None)
 
     
     # Element {http://www.w3.org/2005/08/addressing}ReferenceParameters uses Python identifier ReferenceParameters
-    __ReferenceParameters = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'ReferenceParameters'), 'ReferenceParameters', '__httpwww_w3_org200508addressing_EndpointReferenceType_httpwww_w3_org200508addressingReferenceParameters', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 33, 1), )
+    __ReferenceParameters = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'ReferenceParameters'), 'ReferenceParameters', '__httpwww_w3_org200508addressing_EndpointReferenceType_httpwww_w3_org200508addressingReferenceParameters', False, pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 33, 1), )
 
     
     ReferenceParameters = property(__ReferenceParameters.value, __ReferenceParameters.set, None, None)
 
     
     # Element {http://www.w3.org/2005/08/addressing}Metadata uses Python identifier Metadata
-    __Metadata = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Metadata'), 'Metadata', '__httpwww_w3_org200508addressing_EndpointReferenceType_httpwww_w3_org200508addressingMetadata', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 41, 1), )
+    __Metadata = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Metadata'), 'Metadata', '__httpwww_w3_org200508addressing_EndpointReferenceType_httpwww_w3_org200508addressingMetadata', False, pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 41, 1), )
 
     
     Metadata = property(__Metadata.value, __Metadata.set, None, None)
@@ -204,7 +204,7 @@ class ReferenceParametersType (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ReferenceParametersType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 34, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 34, 1)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
@@ -227,7 +227,7 @@ class MetadataType (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'MetadataType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 42, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 42, 1)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
@@ -250,7 +250,7 @@ class AttributedURIType (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'AttributedURIType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 76, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 76, 1)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyURI
@@ -272,7 +272,7 @@ class AttributedUnsignedLongType (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'AttributedUnsignedLongType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 109, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 109, 1)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.unsignedLong
@@ -294,7 +294,7 @@ class AttributedQNameType (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'AttributedQNameType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 118, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 118, 1)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.QName
@@ -316,20 +316,20 @@ class ProblemActionType (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ProblemActionType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 129, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 129, 1)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
     # Element {http://www.w3.org/2005/08/addressing}Action uses Python identifier Action
-    __Action = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Action'), 'Action', '__httpwww_w3_org200508addressing_ProblemActionType_httpwww_w3_org200508addressingAction', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 74, 1), )
+    __Action = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Action'), 'Action', '__httpwww_w3_org200508addressing_ProblemActionType_httpwww_w3_org200508addressingAction', False, pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 74, 1), )
 
     
     Action = property(__Action.value, __Action.set, None, None)
 
     
     # Element {http://www.w3.org/2005/08/addressing}SoapAction uses Python identifier SoapAction
-    __SoapAction = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'SoapAction'), 'SoapAction', '__httpwww_w3_org200508addressing_ProblemActionType_httpwww_w3_org200508addressingSoapAction', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 132, 3), )
+    __SoapAction = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'SoapAction'), 'SoapAction', '__httpwww_w3_org200508addressing_ProblemActionType_httpwww_w3_org200508addressingSoapAction', False, pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 132, 3), )
 
     
     SoapAction = property(__SoapAction.value, __SoapAction.set, None, None)
@@ -353,15 +353,15 @@ class RelatesToType (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'RelatesToType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 51, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 51, 1)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyURI
     
     # Attribute RelationshipType uses Python identifier RelationshipType
     __RelationshipType = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'RelationshipType'), 'RelationshipType', '__httpwww_w3_org200508addressing_RelatesToType_RelationshipType', _module_typeBindings.RelationshipTypeOpenEnum, unicode_default='http://www.w3.org/2005/08/addressing/reply')
-    __RelationshipType._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 54, 4)
-    __RelationshipType._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 54, 4)
+    __RelationshipType._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 54, 4)
+    __RelationshipType._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 54, 4)
     
     RelationshipType = property(__RelationshipType.value, __RelationshipType.set, None, None)
 
@@ -376,55 +376,55 @@ _module_typeBindings.RelatesToType = RelatesToType
 Namespace.addCategoryObject('typeBinding', 'RelatesToType', RelatesToType)
 
 
-EndpointReference = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'EndpointReference'), EndpointReferenceType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 22, 1))
+EndpointReference = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'EndpointReference'), EndpointReferenceType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 22, 1))
 Namespace.addCategoryObject('elementBinding', EndpointReference.name().localName(), EndpointReference)
 
-ReferenceParameters = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ReferenceParameters'), ReferenceParametersType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 33, 1))
+ReferenceParameters = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ReferenceParameters'), ReferenceParametersType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 33, 1))
 Namespace.addCategoryObject('elementBinding', ReferenceParameters.name().localName(), ReferenceParameters)
 
-Metadata = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Metadata'), MetadataType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 41, 1))
+Metadata = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Metadata'), MetadataType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 41, 1))
 Namespace.addCategoryObject('elementBinding', Metadata.name().localName(), Metadata)
 
-MessageID = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'MessageID'), AttributedURIType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 49, 1))
+MessageID = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'MessageID'), AttributedURIType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 49, 1))
 Namespace.addCategoryObject('elementBinding', MessageID.name().localName(), MessageID)
 
-ReplyTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ReplyTo'), EndpointReferenceType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 70, 1))
+ReplyTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ReplyTo'), EndpointReferenceType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 70, 1))
 Namespace.addCategoryObject('elementBinding', ReplyTo.name().localName(), ReplyTo)
 
-From = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'From'), EndpointReferenceType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 71, 1))
+From = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'From'), EndpointReferenceType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 71, 1))
 Namespace.addCategoryObject('elementBinding', From.name().localName(), From)
 
-FaultTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'FaultTo'), EndpointReferenceType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 72, 1))
+FaultTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'FaultTo'), EndpointReferenceType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 72, 1))
 Namespace.addCategoryObject('elementBinding', FaultTo.name().localName(), FaultTo)
 
-To = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'To'), AttributedURIType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 73, 1))
+To = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'To'), AttributedURIType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 73, 1))
 Namespace.addCategoryObject('elementBinding', To.name().localName(), To)
 
-Action = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Action'), AttributedURIType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 74, 1))
+Action = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Action'), AttributedURIType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 74, 1))
 Namespace.addCategoryObject('elementBinding', Action.name().localName(), Action)
 
-RetryAfter = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'RetryAfter'), AttributedUnsignedLongType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 108, 1))
+RetryAfter = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'RetryAfter'), AttributedUnsignedLongType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 108, 1))
 Namespace.addCategoryObject('elementBinding', RetryAfter.name().localName(), RetryAfter)
 
-ProblemHeaderQName = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ProblemHeaderQName'), AttributedQNameType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 117, 1))
+ProblemHeaderQName = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ProblemHeaderQName'), AttributedQNameType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 117, 1))
 Namespace.addCategoryObject('elementBinding', ProblemHeaderQName.name().localName(), ProblemHeaderQName)
 
-ProblemIRI = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ProblemIRI'), AttributedURIType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 126, 1))
+ProblemIRI = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ProblemIRI'), AttributedURIType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 126, 1))
 Namespace.addCategoryObject('elementBinding', ProblemIRI.name().localName(), ProblemIRI)
 
-ProblemAction = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ProblemAction'), ProblemActionType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 128, 1))
+ProblemAction = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ProblemAction'), ProblemActionType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 128, 1))
 Namespace.addCategoryObject('elementBinding', ProblemAction.name().localName(), ProblemAction)
 
-RelatesTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'RelatesTo'), RelatesToType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 50, 1))
+RelatesTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'RelatesTo'), RelatesToType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 50, 1))
 Namespace.addCategoryObject('elementBinding', RelatesTo.name().localName(), RelatesTo)
 
 
 
-EndpointReferenceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Address'), AttributedURIType, scope=EndpointReferenceType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 25, 3)))
+EndpointReferenceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Address'), AttributedURIType, scope=EndpointReferenceType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 25, 3)))
 
-EndpointReferenceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ReferenceParameters'), ReferenceParametersType, scope=EndpointReferenceType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 33, 1)))
+EndpointReferenceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ReferenceParameters'), ReferenceParametersType, scope=EndpointReferenceType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 33, 1)))
 
-EndpointReferenceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Metadata'), MetadataType, scope=EndpointReferenceType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 41, 1)))
+EndpointReferenceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Metadata'), MetadataType, scope=EndpointReferenceType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 41, 1)))
 
 def _BuildAutomaton ():
     # Remove this helper function from the namespace after it is invoked
@@ -433,30 +433,30 @@ def _BuildAutomaton ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 26, 3))
+    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 26, 3))
     counters.add(cc_0)
-    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 27, 3))
+    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 27, 3))
     counters.add(cc_1)
-    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 28, 3))
+    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 28, 3))
     counters.add(cc_2)
     states = []
     final_update = set()
-    symbol = pyxb.binding.content.ElementUse(EndpointReferenceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Address')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 25, 3))
+    symbol = pyxb.binding.content.ElementUse(EndpointReferenceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Address')), pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 25, 3))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(EndpointReferenceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'ReferenceParameters')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 26, 3))
+    symbol = pyxb.binding.content.ElementUse(EndpointReferenceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'ReferenceParameters')), pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 26, 3))
     st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
     states.append(st_1)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_1, False))
-    symbol = pyxb.binding.content.ElementUse(EndpointReferenceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Metadata')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 27, 3))
+    symbol = pyxb.binding.content.ElementUse(EndpointReferenceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Metadata')), pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 27, 3))
     st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
     states.append(st_2)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_2, False))
-    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, 'http://www.w3.org/2005/08/addressing')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 28, 3))
+    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, 'http://www.w3.org/2005/08/addressing')), pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 28, 3))
     st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
     states.append(st_3)
     transitions = []
@@ -498,12 +498,12 @@ def _BuildAutomaton_ ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 36, 3))
+    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 36, 3))
     counters.add(cc_0)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 36, 3))
+    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 36, 3))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     transitions = []
@@ -523,12 +523,12 @@ def _BuildAutomaton_2 ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 44, 3))
+    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 44, 3))
     counters.add(cc_0)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 44, 3))
+    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 44, 3))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     transitions = []
@@ -541,9 +541,9 @@ MetadataType._Automaton = _BuildAutomaton_2()
 
 
 
-ProblemActionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Action'), AttributedURIType, scope=ProblemActionType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 74, 1)))
+ProblemActionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Action'), AttributedURIType, scope=ProblemActionType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 74, 1)))
 
-ProblemActionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'SoapAction'), pyxb.binding.datatypes.anyURI, scope=ProblemActionType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 132, 3)))
+ProblemActionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'SoapAction'), pyxb.binding.datatypes.anyURI, scope=ProblemActionType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 132, 3)))
 
 def _BuildAutomaton_3 ():
     # Remove this helper function from the namespace after it is invoked
@@ -552,19 +552,19 @@ def _BuildAutomaton_3 ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 131, 3))
+    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 131, 3))
     counters.add(cc_0)
-    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 132, 3))
+    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 132, 3))
     counters.add(cc_1)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(ProblemActionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Action')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 131, 3))
+    symbol = pyxb.binding.content.ElementUse(ProblemActionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Action')), pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 131, 3))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_1, False))
-    symbol = pyxb.binding.content.ElementUse(ProblemActionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'SoapAction')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 132, 3))
+    symbol = pyxb.binding.content.ElementUse(ProblemActionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'SoapAction')), pyxb.utils.utility.Location('/tmp/pyxbdist.WUiBAra/PyXB-1.2.6/pyxb/bundles/wssplat/schemas/wsa.xsd', 132, 3))
     st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_1)
     transitions = []
