@@ -584,7 +584,7 @@ import os
 import re
 class TestGetMatchingFiles (unittest.TestCase):
     __WXS_re = re.compile('\.wxs$')
-    __NoExt_re = re.compile('^[^\.]*$')
+    __NoExt_re = re.compile('(^|\%s)[^\.]+$' % os.sep)
     __directory = None
     def setUp (self):
         self.__directory = tempfile.mkdtemp()
